pub struct ReceivingBox {
pub arrived_date: Option<DateTime<Utc>>,
pub box_items: Vec<ReceivingBoxItem>,
pub box_number: i64,
pub box_status: Option<ReceivingBoxStatus>,
pub counting_started_date: Option<DateTime<Utc>>,
pub received_date: Option<DateTime<Utc>>,
pub tracking_number: String,
}Expand description
Information about a box shipment included in a receiving order
Fields
arrived_date: Option<DateTime<Utc>>Expiration date for this lot
box_items: Vec<ReceivingBoxItem>Information about the items included in the box
box_number: i64Information about a box shipment included in a receiving order
box_status: Option<ReceivingBoxStatus>Information about a box shipment included in a receiving order
counting_started_date: Option<DateTime<Utc>>Expiration date for this lot
received_date: Option<DateTime<Utc>>Expiration date for this lot
tracking_number: StringName of the channel